@@ -15,10 +15,14 @@ from je_editor.ui.ui_event.execute.execute_shell_command.run_on_shell import exe
 from je_editor.ui.ui_event.open_file.open_file_to_read.open_file_to_read import open_file_to_read
 from je_editor.ui.ui_event.open_file.open_last_edit_file.open_last_edit_file import open_last_edit_file
 from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_to_open
+from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_then_can_run
 from je_editor.utils.code_tag.tag_keyword import HighlightText
 from je_editor.utils.editor_content.content_save import open_content_and_start
 from je_editor.utils.text_process.program_exec.exec_text import ExecManager
 from je_editor.utils.text_process.program_exec.process_error import process_error_text
+from je_editor.ui.ui_utils.font.font import get_font
+from je_editor.ui.ui_event.change_font.change_font import change_font
+from je_editor.ui.ui_event.change_font.change_font import change_font_size
 
 
 def start_editor(use_theme=None):
@@ -27,13 +31,9 @@ def start_editor(use_theme=None):
 
 class EditorMain(object):
 
-    # start auto save
-    def start_auto_save(self):
-        self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
-
     # start editor and start auto save if auto save not start
     def start_editor(self):
-        self.start_auto_save()
+        self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
         self.main_window.mainloop()
 
     # editor close event
@@ -46,23 +46,22 @@ class EditorMain(object):
         self.file_from_output_content = temp
         self.current_file = temp
         self.highlight_text.search()
-        self.start_auto_save()
+        self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
 
     # save editor file
     def save_file_to_open(self, event=None):
         self.current_file = save_file_to_open(self.code_editor)
-        self.start_auto_save()
+        self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
 
     def open_last_edit_file(self):
         self.highlight_text.search()
         return open_last_edit_file(self.file_from_output_content, self.code_editor)
 
-    def exec_code(self, event=None):
+    def execute_program(self, event=None):
+        if self.current_file is not None:
+            save_file_then_can_run(self.current_file, self.code_editor)
         execute_code(self.run_result, self.current_file, self.save_file_to_open, self.exec_manager)
 
-    def run_on_shell(self, event=None):
-        execute_shell_command(self.run_result, self.code_editor)
-
     def show_popup_menu(self, event):
         """
         :param event: tkinter event bind Button-3
@@ -114,9 +113,11 @@ class EditorMain(object):
         self.run_result_scrollbar_y.grid(column=1, row=1)
         self.run_result.configure(state="disabled")
         self.run_result.bind("<1>", lambda event: self.run_result.focus_set())
-        self.exec_manager = ExecManager(run_result=self.run_result,
-                                        process_error_function=process_error_text,
-                                        main_window=self.main_window)
+        self.exec_manager = ExecManager(
+            run_result=self.run_result,
+            process_error_function=process_error_text,
+            main_window=self.main_window
+        )
         # Menubar
         # Main menu
         self.menu = tkinter.Menu(self.main_window)
@@ -126,20 +127,50 @@ class EditorMain(object):
         self.file_menu.add_command(label="Open File", command=self.open_file_to_read)
         # Function menu
         self.function_menu = tkinter.Menu(self.menu, tearoff=0)
-        self.function_menu.add_command(label="Run", command=self.exec_code)
-        self.function_menu.add_command(label="Run on shell", command=self.run_on_shell)
+        self.function_menu.add_command(
+            label="Run",
+            command=self.execute_program
+        )
+        self.function_menu.add_command(
+            label="Run on shell",
+            command=lambda: execute_shell_command(self.run_result, self.code_editor)
+        )
+        # Text menu
+        self.text_menu = tkinter.Menu(self.menu, tearoff=0)
+        self.text_font_sub_menu = tkinter.Menu(self.text_menu, tearoff=0)
+        self.text_size_sub_menu = tkinter.Menu(self.text_menu, tearoff=0)
+        self.font_tuple = get_font(self.main_window)
+        for i in range(len(self.font_tuple)):
+            self.text_font_sub_menu.add_command(
+                label=str(self.font_tuple[i]),
+                command=lambda my_font=self.font_tuple[i]: change_font(self.code_editor, self.run_result, my_font)
+            )
+        for i in range(12, 36, 2):
+            self.text_size_sub_menu.add_command(
+                label=str(i),
+                command=lambda font_size=i: change_font_size(self.code_editor, self.run_result, font_size)
+            )
+        self.text_menu.add_cascade(label="Font", menu=self.text_font_sub_menu)
+        self.text_menu.add_cascade(label="Font Size", menu=self.text_size_sub_menu)
+        # add and config
+        self.menu.add_cascade(label="File", menu=self.file_menu)
+        self.menu.add_cascade(label="Function", menu=self.function_menu)
+        self.menu.add_cascade(label="Text", menu=self.text_menu)
+        self.main_window.config(menu=self.menu)
         # Popup menu
         self.popup_menu = Menu(self.main_window, tearoff=0)
-        self.popup_menu.add_command(label="Run", command=self.exec_code)
-        self.popup_menu.add_command(label="Run on shell", command=self.run_on_shell)
+        self.popup_menu.add_command(
+            label="Run",
+            command=self.execute_program
+        )
+        self.popup_menu.add_command(
+            label="Run on shell",
+            command=lambda: execute_shell_command(self.run_result, self.code_editor)
+        )
         self.popup_menu.add_separator()
         self.popup_menu.add_command(label="Save File", command=self.save_file_to_open)
         self.popup_menu.add_command(label="Open File", command=self.open_file_to_read)
         self.main_window.bind("<Button-3>", self.show_popup_menu)
-        # add and config
-        self.menu.add_cascade(label="File", menu=self.file_menu)
-        self.menu.add_cascade(label="Function", menu=self.function_menu)
-        self.main_window.config(menu=self.menu)
         # set resize
         self.code_edit_frame.columnconfigure(0, weight=1)
         self.code_edit_frame.rowconfigure(0, weight=1)
@@ -161,12 +192,17 @@ class EditorMain(object):
         # bind
         self.main_window.bind("<Control-Key-o>", self.open_file_to_read)
         self.main_window.bind("<Control-Key-s>", self.save_file_to_open)
-        self.main_window.bind("<Control-Key-F5>", self.exec_code)
-        self.main_window.bind("<Control-Key-F6>", self.run_on_shell)
+        self.main_window.bind(
+            "<Control-Key-F5>",
+            self.execute_program
+        )
+        self.main_window.bind(
+            "<Control-Key-F6>",
+            lambda bind_exec_shell_command: execute_shell_command(self.run_result, self.code_editor)
+        )
         # is this test run?
         self.test_run = False
         # Auto save thread
         self.auto_save = None
         if self.current_file is not None:
             self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
-
